% plot a cumulative blackbody spectrum
clear
T = [5000 3000];
lmax = 2897.8E-6 / min(T); 
lambda = logspace(-1, 2, 400)'*lmax;
lvis = [390 700]*1e-9;   

% mcd = load('mcd.mat');
% tinox = load('tinox.mat')
% BK7 = load('SPIE_p107.mat');

% limits = [0 Inf; 0 Inf; 3e-7 4e-6];

X = [];
[X(1).lambda, X(1).EL] = am1p5;


[X(2).EL, IL, X(2).lambda] = bb_spectrum(2869, lambda);
for i = 1:2,
    X(i).CEL = cumtrapz(X(i).lambda, X(i).EL);
    X(i).SpecPower = X(i).CEL(end);
    X(i).CELnd = X(i).CEL/X(i).SpecPower;
end


%plot(lambda, EL)
hold off
cla
set(gcf,'defaultlinelinewidth', 1.5)
subplot(1,2,1)
%yyaxis left
%hp = patch(lvis([1 2 2 1]), [0 0 1 1], [1 1 1]*0.9);
%hold on
hl1 = semilogx(X(1).lambda, X(1).CELnd, X(2).lambda, X(2).CELnd);
ht = text(0.55e-6, 0.6, 'visible');set(ht, 'rot',90)
%hold off
hold on
hv = [vertical(lvis(1)), vertical(lvis(2))];
set(hv, 'linestyle','--','linewidth', 0.5', 'color','k')
title('Illumination spectra')
xlabel('Wavelength (m)')
ylabel('Cumulative power fraction')
axis([3e-7 5e-6 0 1]); 
legend(hl1, {'AM1.5','2869 K black body'})
grid on

subplot(1,2,2)
%yyaxis right
mcd = load('mcd.mat');
tinox = load('tinox.mat');
BK7 = load('SPIE_p107.mat'); % .XY = [nm, internal transmittance for 25 mm thick]
BK7.XY(:,1) = BK7.XY(:,1)*1E-9;
BK7.f_4mm = BK7.XY(:,2).^(4/25);
cmp11 = load('cmp11.mat');

hl2 = semilogx(tinox.XY(:,1),1-tinox.XY(:,2), mcd.XY(:,1), 1-mcd.XY(:,2), BK7.XY(:,1), 1-BK7.f_4mm, cmp11.XY(:,1), cmp11.XY(:,2), '--');
title('Absorbance spectra')
xlabel('Wavelength (m)')
ylabel('Absorbance & sensitivity')

legend(hl2, {'Tinox Energy', 'Black chrome','BK7 glass', 'CMP11 sensitivity'})
axis([3e-7 5e-6 0 1])

grid
hold off
%-------------------------------------------------------------

% now integrate AM1.5

% first interpolate absorbance onto lambda values
  %  Vq = interp1(X,V,Xq,METHOD,EXTRAPVAL)
  
  
  for i = 1:2  % AM1.5, 3000 K spectra
      X(i).AB = interp1(tinox.XY(:,1), 1-tinox.XY(:,2), X(i).lambda, 'linear', 0);
      X(i).AB(:,2) = interp1(mcd.XY(:,1), 1-mcd.XY(:,2), X(i).lambda, 'linear', 0);
      X(i).AB(:,3) = interp1(BK7.XY(:,1), 1-BK7.f_4mm, X(i).lambda, 'linear', 1);
      X(i).CT_AB = cumtrapz(X(i).lambda, X(i).AB.*X(i).EL(:, [1 1 1])) / X(i).SpecPower;
      max(X(i).CT_AB)
  end


semilogx(X(1).lambda, X(1).CT_AB, X(2).lambda, X(2).CT_AB)
axis([3e-7 5e-6 0 1])
%-------------------------------------------------------

% Now calculate combined tau.alpha mean values
r = 0.0417;

for i = 1:2  % AM1.5, 3000 K spectra
    for j = 1:2,  % coating = tinox, black chrome
        [ta, alpha_go] = find_tau_alpha(1-X(i).AB(:,3), r, X(i).AB(:,j));
        X(i).CT_ta(:,j) = cumtrapz(X(i).lambda, ta.*X(i).EL)/ X(i).SpecPower;
        X(i).CT_ago(:,j) = cumtrapz(X(i).lambda, alpha_go.*X(i).EL)/ X(i).SpecPower;
        TA1(2*j-1, i) = X(i).CT_ago(end,j);
        TA1(2*j, i) = X(i).CT_ta(end,j);
    end
end

TA1
TA1*100

 % make table

