function [ifit, hdata, hfit] = ifit_fitting(t, y, id, type, abc)
% [ifit, hdata, hfit] = ifit_fitting(t, y, id, type)
% e.g. ifit = exp_fitting(t, Q, 'Q', 'exp_abc') or ...,'poly1')
% id is just a name that appears so the structure is more readable
%
%
% RWM

if strcmp(type, 'exp_abc')
    ft = fittype('a + b * (1 - exp(-c*x))');
    if nargin<5,
        a = y(1);
        b = 1.1*(y(end)-y(1));
        c = 0.0004;
        abc = [a b c];
    end
    
    curve1 = fit(t, y, ft, 'StartPoint', abc);
    assy = curve1.a + curve1.b;  % = 827.3
    % for large time constant multiples, the assymptote is not sensible!
    % Instead, get value and gradient at final t (same for all the ifits)
    % gradient = bc exp(-cx)
    ep = curve1(t(end));
    slope = curve1.b * curve1.c * exp(-curve1.c * t(end));
    Tconst = 1 / curve1.c;
    disp(['Finishes ' sprintf('%0.2f', (ep/assy-1)*100) '% above assymptote'])
elseif strcmp(type, 'poly1')
    ft = fittype('poly1');
    curve1 = fit(t, y, ft);
    assy = NaN;
    ep = curve1(t(end));
    slope = curve1.p1;
    Tconst = NaN;
elseif strcmp(type, 'poly2')
    ft = fittype('poly2');
    curve1 = fit(t, y, ft);
    assy = NaN;
    ep = curve1(t(end));
    slope = curve1.p1;
    Tconst = NaN;
else
    error('type should be exp_abc or poly1')
end

TCmult = (t(end)-t(1))/Tconst; 
ifit.assy = assy;
ifit.curve = curve1;
%------------------------------------
ifit.final_vs = [ep slope];
%-------------------------------------
ifit.id = id;
ifit.type = type;
ifit.y = y;
ifit.TCmult = TCmult;
ifit.TConst = Tconst;
%-------------------------------------
hdata = plot(t,y);
hold on
hfit = plot(ifit.curve)
ylabel(id)
title([num2str(ifit.TCmult) ' time constants'])
hold off


