function [Pout, isSub] = lamp_settings(arg1, arg2)
% [Pout, isSub] = lamp_settings(arg1, arg2)
% Use to either predict the power required or calculate the illumination.
%
% lamp_settings('123', 800)  gives mean illumination
% for lamps 123 with 800 W input.
%
% If the lamp combination is not specified, will try to guess an equivalent
% (e.g. "1" instead of "2"); in this case, isSub = 1
%
% lamp_settings(800) will show combinations of lamps that could make
% 800W

S = load('lampcals.mat');
% S.lamplist
% 1234
% 123 
% 14  
% 23  
% 1 

if nargin==1
    % if P = p(1)x^2 + p(2)x + p(3), x = roots(p=[0 0 P])
    for i = 1:length(S.lampfullIP),
        frac_reqd = arg1 / S.lampfullIP(i); % this fraction of full input power for these lamps
        % = y-axis on graph
        % initial effy guess = 0.7
        if frac_reqd<0.795,
            X = fzero(@(x) lampOPfn(x, S.plamp, frac_reqd), -5, 0);
            fP = exp(X);
            P = fP * S.lampfullIP(i);
            disp(S.lamplist(i,:)); disp(P)
        end
    end
    
elseif nargin ==2
    lookups = {'1234', '1234'
        '123 ', '123'
        '124 ', '123'
        '134 ', '123'
        '234 ', '123'
        '14  ', '14'
        '12  ', '14'
        '13  ', '14'
        '23  ', '23'
        '24  ', '23'
        '34  ', '23'
        '1   ', '1'
        '2   ', '1'
        '3   ', '1'
        '4   ', '1'};
    lamp = [char(arg1), blanks(4-length(arg1))];
    isSub = 0;
    if isempty(arg1),
        disp('Lights OFF!')
        if any(arg2), 
            error('Why is power not zero?')
        end
        P = 0;
    else
        combo = textfind(lookups(:,1), lamp);
        if isempty(combo), error(['lamp combination ' arg1 ' is weird']); end
        okname = char(lookups(combo, 2));
        if ~strcmp(arg1, okname),
            disp(['Lamps ' arg1 ' are interpreted as ' okname ', OK??????'])
            isSub = 1;
        end
        okname = [okname, blanks(4 - length(okname))];
        mode = textfind(S.lamplist, okname, 1);
        modefrac = S.lampfrac(mode);  % 100% power for this mode
        
        lampfullIP = S.lampfullIP(mode);
        frac_p = arg2 / lampfullIP;
        P = polyval(S.plamp, log(frac_p)) * arg2;
        displ2(P, 'Watts/m^2')
    end
else
    error('Use 1 or 2 input arguments please')
end

if nargout>0, Pout = P; end


function out = lampOPfn(x, plamp, target)
% from lamp_patterns:
%frac_m2 = ILvP ./ PvP(2,:);  % fraction of actual (not maximum) input power delivered as heat to 1 m^2
%frac_p = PvP(2,:) / PvP(2,1);
%plamp = polyfit(log(frac_p), frac_m2, 2);
%
% Hence frac_m2 = Outputpower/m^2 / inputpower = polyval(plamp, log(inputpower / max input power))
% Outputpower/m^2  = polyval(plamp, log(inputpower / max input power)) * inputpower
 

pred = polyval(plamp, x) .* exp(x);
out = pred - target;



