function [S, fp] = loadconv_f1(fname)
% S = loadconv2(fname)
% load solar collector LabView data file and convert to engineering units
% for collector 2 (Farid's first one)
%
% n.b.  some tests require outlet temperature based on only 1 RTD or with a
% correction applied to the mean.
% This must be done in the "test16....m" processing file, NOT HERE!!!
%
% Similarly the "glass temperature" is the thermocouple reading.  If you
% want to take off 0.7 deg C, do it later!
% RWM

s = load(fname);
S.Test_Date = s.Test_Date;
S.TComment = s.TComment;
S.srate = s.srate;
S.Gnam = s.Gnam;
S.GComment = s.GComment;
S.AnyMissed = s.AnyMissed;
S.FromFile = s.FromFile;
S.time = s.time;


[cals, found] = readcals('RTD_TC_CORcalMar16.mat', s.Gnam);
% This knows calibrations for the RTDs, thermocouples and Coriolis mass flow
% meter
% RTD1    50.708    -100.43  
% RTD2    50.71     -101.8   
% RTD3    50.753    -102.06  
% RTD4    50.844    -102.13  
% RTD5    50.657    -101.85  
% RTD6    53.197    -108.08  
% RTD7    50.927    -102.2   
% RTD8    120.04    -0.60743 
% RTD9    120.39    -1.2225  
% RTD10   120.17    -0.85486 
% RTD101  68.904    -278.05  
% RTD102  124.03    -1.63    
% TC202   0.98867   0.67589  
% TC203   0.99089   0.60847  
% TC204   0.96793   1.1004   
% TC205   0.99185   -0.031348
% TC302   0.99179   0.1226   
% Cor1    0.0074997 -0.0075 

% displ(S.Gnam, [cals, found])

for i = 1:size(s.data, 2), 
    if found(i),
        ch(:,i) = polyval(cals(i,:), s.data(:,i));
    else
        ch(:,i) = s.data(:,i);
    end
end
S.ch = ch;  % channels
S.mioT = [mean(ch(:, [1 2])')', mean(ch(:, [3 4])')'];
S.dT = S.mioT(:,2)-S.mioT(:,1);

%--------------------------------------------
transducer_names = {
    'TC202', 'TC209'   % top glass
    'TC203', 'TC201'  % tray or bottom glass
    };

ff = eval(S.FromFile(4:9));  % date as integer 
if ff < 160429,
    disp('File identified as collector P1')
    tb_gl = transducer_names(:,1);
else
    disp('File identified as collector F1')
     tb_gl = transducer_names(:,2);
end
%------------------------------------------------------

S.ambch = textfind(S.Gnam, 'TC302');
S.Tam = mean(S.mioT')' - S.ch(:, S.ambch);  % ambient to collector mean
S.T_top_ch = [textfind(S.Gnam, 'TC209'), textfind(S.Gnam, 'TC207')]; % middle, pin
S.T_top = S.ch(:, S.T_top_ch);
S.T_bot_ch = [textfind(S.Gnam, 'TC201'), textfind(S.Gnam, 'TC208')]; % middle, pin
S.T_bottom = S.ch(:, S.T_bot_ch);
S.T_seal_ch = textfind(S.Gnam, 'TC210');
S.T_seal = S.ch(:, S.T_seal_ch);

%-------------------------------------------
flowch = textfind(s.Gnam, 'Cor1');
S.massflow = S.ch(:, flowch);
%---------------------------------------
IGchan = textfind(s.Gnam, 'IGCG1');
S.p = 10 .^ (2*(S.ch(:, IGchan)-4.5)); % non-linear hence not processed with other channels above

S.Power = S.ch(:, textfind(lower(S.Gnam), 'pow')); % may be POW or Pow1, whoops!
S.Power = v2power(S.Power); % all 5 range possibilities

fp = fluid_properties('water', [], S.mioT(1));
%---------------------------------------
pychan = textfind(lower(S.Gnam), 'pyr');
if any(pychan)
   S.pyro = S.ch(:, pychan)/(18.86 * 8.66E-6); 
   % 18.86 is amplifier gain (calculated from resistance values - 
   % calibration result (from memory) was close enough to this to make no
   % difference
   % 8.66E-6 is sensitivity of RWM's pyranometer.
   disp('Guess - please check exact amplifier gain!!')
else
   S.pyro = [];
end