function [p, Vint, Vtrapz, area] = polyfit2d(X, Y, Z, PXY, xylims)
% [p, Vint, Vtrapz, area] = polyfit2d(X, Y, Z, PXY, xylims)
%
% This fits a polynomial surface of the form
% Z = sigma(i,j)(p_ij * x^PXi * y^PYj)
% where indices PXi are taken from PXY(:,:,1) and
% PYi from PXY(:,:,2) or PXY(:,1), PXY(:,2)
%
% Typically X, Y are like [X,Y]=ndgrid(1:2, 4:6)
% Vint is volume under the polynomial surface
% Vtraz ditto using trapezium rule and assuming data points are uniformly
% spaced
%
% You can /area to get mean value
% RWM

np = length(Z(:));

spxy = size(PXY);
if length(spxy)>3,
    error('Too many dimensions for PXY')
elseif length(spxy)==3, 
    nindex = prod(spxy(1:2));
    PXY = reshape(PXY, [nindex spxy(3)]);
    spxy = size(PXY);
end
if spxy(1)>np, error('Too high a curve order to fit this many points'); end
if spxy(2)~=2, error('Need powers for both x and y'); end
%----------------------------------------

nindex = spxy(1);
VDM = zeros(np, nindex);
Xc = X(:); Yc = Y(:); Zc = Z(:);
if length(Xc)~=np, error('Wrong number of points in Xc'); end
if length(Yc)~=np, error('Wrong number of points in Yc'); end

for i = 1:nindex,
   VDM(:,i) =  Xc.^PXY(i,1) .* Yc.^PXY(i,2);
end

% solve VDN * p = Z
p = (VDM \ Zc)';

%----------------------------------------------
% integrate area under each surface over a rectangle
if nargout>1,
    if nargin<5,
      xylims = [min(Xc) max(Xc) min(Yc) max(Yc)];
    end
    Vint = 0;
    for i = 1:nindex
        Vint = Vint + p(i) * defint(PXY(i,1), xylims(1:2)) * defint(PXY(i,2), xylims(3:4));
    end
    weights = ones(size(Z))*4;
    weights(:, [1 end]) = 2;
    weights([1 end],:) = 2;
    weights([1 end], [1 end]) = 1;
    weights = weights / sum(weights(:));
    weighted_Z = weights .* Z;
    Vtrapz = sum(weighted_Z(:));
    
    dxy = xylims([2 4]) - xylims([1 3]);
    area = prod(dxy);
    Vtrapz = Vtrapz * area;
end

%----------------------------------------------------------
function A = defint(m, lims)
% A = defint(m, lims)
% integrate y = x^m between lims(1) and lims(2)
if m == -1
    A = log(lims(2) / lims(1));
else
    lp = lims .^ (m+1);
    A = (lp(2) - lp(1)) / (m+1);
end

