% Measurements of the light distribution from floodlight "4", removed
% from the simulator.  Initially with its original bulb; bulb replaced for
% later test.
% 21/6/17

% Pyranometer moved x,y in 100 mm steps.
% Pyranometer kept vertical i.e. off-axis to light direction

% Centreline, down from top, A-T (20)
V = [1.32 421
    2.12 423
    3.53 422
    6.75 423
    9.07 415
    10.66 415
    13.7 413
    18.9 415
    22.6 414
    24.3 415
    25.1 416
    26   415
    26   414
    25.4 418
    22.8 417
    19.6 416
    14.7 415
    11.6 415
    9.06 415
    6.02 417
    ];
xyv = [zeros(20,1), (11:-1:-8)'*0.1];
% repeat of last point, this time facing the light:
% 7.2, 416

% horizontal centreline a-s (19)
H = [ 4.69 419
    7.08 415
    9.3 416
    12.41 416
    15.93 416
    18.9 416
    21.94 413
    24.4 413
    25.73 413
    25.93 413
    24.3 412
    20.99 412
    18.52 413
    15.6 414
    13.07 412
    9.76 412
    7.51 412
    5.07 413
    3.5 413 ];
xyh = [(-9:9)'*0.1 zeros(19,1)];

% inner box, 400 mm square, from top left
bi = [18.9 413  % top left
    20.75 414
    22.8 413  
    22.9 414  % cl
    21.48 413 
    19.9 412
    17.8 412  % top right
    18.5 412
    18.4 413
    18.8 413  % cl
    17.72 412
    17.64 412
    15.8 414  % bottom right
    18.65 413
    20.6 413
    21.9 414  % cl
    21.7 414
    21.2 413
    19.6 413  % bottom left
    21.4 413
    21.37 413
    21.2 414 % cl
    20.04 413
    19.74 412 ];
    
xyi = [(-3:3)', repmat(3, [7 1])
     repmat(3, [6 1]), (2:-1:-3)'
     (2:-1:-3)', repmat(-3, [6 1])
     repmat(-3, [5 1]), (-2:2)'] * 0.1;
 
     
% outer box
bo = [ 9.25 413
    9.36 413
    9.6 413
    8.86 413 ];
xyo = [-1 1
    1 1
    1 -1
    -1 -1] * 0.5;

% outer box + on-axis points
bo2 = [ 9.25 413
    13.7  413 % axis
    9.36 413
    13.07 412 % axis
    9.6 413
    14.7 415 % axis
    8.86 413 
    15.93 416 ];
xyo2 = [-1 1
    0 1 % axis
    1 1
    1 0 % axis
    1 -1
    0 -1 % axis
    -1 -1
    -1 0 % axis
    ] * 0.5;

% raw data:
all = [V; H; bi; bo]; % 67 pointa
allxy = [xyv; xyh; xyi; xyo];

% add bo2: (duplicate points):
all = [all; bo2];
allxy = [allxy; xyo2];

allxy(:,1) = allxy(:,1)+0.041;  % make more symmetrical
r = sqrt(sum(allxy'.^2)+1)';  % 3D pythagoras
thdeg = atand(sqrt(sum(allxy.^2, 2)));
cth = 1 ./r;


allp = (all(:,1)-0.3) *420./all(:,2);  % correct to 400 Watts, 1 m radius
allp = 0.001 * allp / (18.93*8.66E-6);  % W/m^2
allc = allp .* r.^2 ./ cth;   % ./cth new for pyro3_p.mat

if 0
    nac = length(allc);
    vdM = [ones(nac,1), allxy(:,2), allxy(:,2).^3, allxy.^2, allxy.^4, prod(allxy,2).^2 ];
    p = vdM \ allc;
    allc_pred = vdM * p;
    %all_pred = allc_pred./r
    std(allc - allc_pred)
    
    %[PXY(:,:,1), PXY(:,:,2)] = ndgrid(0:4, 0:4);
    PXY = [0 0
        1 0
        2 0
        3 0
        4 0
        0 1
        0 2
        0 3
        0 4
        1 1
        ];
    p = polyfit2d(allxy(:,1), allxy(:,2), allc, PXY);
    pred2d = polyval2d(p, PXY, allxy(:,1), allxy(:,2));
    std(allc-pred2d)
end

n = [20 19 24 4 8];  % number in each series, stopping before bo2.

figure(1)
set(gcf,'defaultlinelinewidth', 2)
ii = 0;
for i = 1:5
    v = ii + (1:n(i))';
    xy = allxy(v,:);
    G = allp(v);
    
    if i>2
        xy = [xy; xy(1,:)];
        G = [G; G(1)];
    end
    if i~=4
        if i>2
          nG = (length(G)-1)/4
          vv = 1:(nG+1);
          for j = 1:4,
              h = plot3curtain(xy(vv,1), xy(vv,2), G(vv));
              set(h, 'facecolor', [1 1 1]*0.7,'facealpha', 0.4,'meshstyle','column')
              hold on
              plot3(xy(vv(1),1)*[1;1], xy(vv(1),2)*[1;1], [0 G(vv(1))]', '-b', 'linewidth', 2)
              vv = vv + nG
          end
        else
          h = plot3curtain(xy(:,1), xy(:,2), G);
          set(h, 'facecolor', [1 1 1]*0.7,'facealpha', 0.4,'meshstyle','column')
        end
        hold on
        plot3(xy(:,1), xy(:,2), G, '+')
    end
    ii = ii + n(i);
end
%plot3(allxy(:,1), allxy(:,2), pred2d, '*')
%vx = -1.2:0.05:1.5; [xg,yg]=ndgrid(vx,vx); 
%meshpred = polyval2d(p, PXY, xg,yg);
%hs = surf(xg,yg, meshpred);
hold off
xlabel x; ylabel y
grid on
view(-55.5, 51.6);
axis tight
set(gca,'clipping','off')
set(gca,'pos', [0.1 0.05 0.85 0.9])
set(gca, 'DataAspectRatio', [1 1 200])
zlabel('Illumination (W/m^2)')


figure(2)
set(gcf,'defaultlinelinewidth', 2)
ii = 0;
xVH = []; GVH = [];
for i = 1:2
    v = ii + (1:n(i))';
    xy = allxy(v,:);
    ri = r(v);
    G = allc(v);
    ij = 3-i;
    %p2(i).p = polyfit(xy(:, ij), G, 4); 
    %GP = polyval(p2(i).p, xy(:, ij)); 
    %std(GP-G)    
    %plot(xy(:, ij), G, '-+')
    thdeg = atand(xy(:, ij));
    plot(thdeg, G, '-+')
    xVH = [xVH; xy(:, ij)];
    GVH =  [GVH; G];
    hold on
    ii = ii + n(i);
end

v = 40:67;  % box points
xVH = sqrt(sum(allxy(v,:).^2, 2));
thdeg = atand(xVH);
G = allc(v);
plot(thdeg, G, 'o')

% plot3(allxy(:,1), allxy(:,2), pred2d, '*')
% v = -0.9:0.05:0.9; [xg,yg]=ndgrid(v,v); 
% meshpred = polyval2d(p, PXY, xg,yg);
% hs = surf(xg,yg, meshpred);
if 1
    % fit in terms of r^2
    xVH2 = sum(allxy(1:39,:).^2, 2);
    vdM = [xVH2.^2, xVH2, ones(39,1)];
    p = vdM \ GVH; p = [p(1) 0 p(2) 0 p(3)];
    
    vx = -0.9:0.05:0.9; [xg,yg]=ndgrid(vx,vx);
    GP = polyval(p, vx);
    %p2(3).p = polyfit(xVH, GVH, 4); GP = polyval(p2(3).p, vx);
end

% fit in terms of theta^2
thdeg = atand(sqrt(xVH2));
vdM = [thdeg.^4, thdeg.^2, ones(39,1)];
p = vdM \ GVH; p = [p(1) 0 p(2) 0 p(3)];
GP = polyval(p, atand(vx));
% save pyro2_p.mat p % without cos(theta) correction
save pyro3_p.mat p  % with cos(theta) correction


plot(atand(vx), GP, '--')
hold off
xlabel('Angle off-axis (\circ)'); ylabel('Illumination (W/m^2)')
grid on
legend({'Vertical axis','Horizontal axis','Off-axis','Curve fit'})  
axis([-50 50 0 170])
%------------------------------------
% GET OVERALL ERROR
th_2d = atand(sqrt(sum(allxy(1:67,:).^2, 2)));
GP = polyval(p, th_2d);
std(allc(1:67)-GP)

% bi = [bi; bi(1,:)];
% xyi = [xyi; xyi(1,:)];
% bo = [bo; bo(1,:)];
% xyo = [xyo; xyo(1,:)];
% 
% 
% h = plot3(xyh(:,1), xyh(:,2), H(:,1), xyv(:,1), xyv(:,2), V(:,1),...
%     xyi(:,1), xyi(:,2), bi(:,1), xyo(:,1), xyo(:,2), bo(:,1));
% set(h, 'marker', '+')
% xlabel x; ylabel y


%======================================================
% Next, time history of a NEW bulb warming up.
if 0
    tpP = [
        0 27.3 423
        1 26.78 422
        2 26.96 423
        3 27.16 423
        4 26.98 422
        5 26.81 423
        6 26.78 422
        7 26.72 423
        8 26.53 423
        9 26.79 423
        10 26.54 419
        17 26.65 419
        22 27   422
        38 27.16 423 ];
    tpP(:,1) = 10 + tpP(:,1)*60; % seconds
    
    % add 2 rows which are the OLD bulb:
    tpP = [0 26 415
        0 25.93 413
        tpP ];
    tpP(:,2) = 0.001 * (tpP(:,2)-0.3).* (420./tpP(:,3)) / (18.93*8.66E-6);  % scale to 420 W assuming const eta
    
    plot(tpP(:,1), tpP(:,2), '-+')
    old_new = [mean(tpP(1:2,2)) mean(tpP(3:end,2))]
    %   162.7463  165.1604
    % old_new(2)/old_new(1) =    1.0148
    % new bulb 1.5% brighter than old bulb at same power, central position
    % but new one has same brightness at 500 seconds
    
end